package be.iminds.ilabt.jfed.espec.model;

import javax.annotation.Nonnull;
import javax.annotation.Nullable;
import java.util.Collections;
import java.util.List;

/**
 * FileSource
 */
public class GeneratedRSpecFileSource extends FileSource {
    @Nonnull private final String am; //urn or serverId
    @Nullable private final String resourceClass;
    private final int nodeCount;
    @Nonnull private final String nodeNamePrefix;
    @Nonnull private final List<String> nodeNames;

    public GeneratedRSpecFileSource(@Nonnull SourceType sourceType, @Nonnull String value, @Nonnull String basename,
                                    @Nonnull String am, @Nullable String resourceClass,
                                    int nodeCount, @Nullable String nodeNamePrefix, @Nullable List<String> nodeNames) {
       super(sourceType, value, basename);
       this.am = am;
       this.resourceClass = resourceClass;

       this.nodeNamePrefix = nodeNamePrefix == null ? "n" : nodeNamePrefix;
       this.nodeNames = nodeNames == null ? Collections.emptyList() : nodeNames;
       this.nodeCount = nodeCount;
    }

    @Nonnull
    public String getAm() {
        return am;
    }

    @Nullable
    public String getResourceClass() {
        return resourceClass;
    }

    public int getNodeCount() {
        return nodeCount;
    }

    @Nonnull
    public String getNodeNamePrefix() {
        return nodeNamePrefix;
    }

    @Nonnull
    public List<String> getNodeNames() {
        return nodeNames;
    }

    @Override
    public boolean equals(Object o) {
        if (this == o) return true;
        if (!(o instanceof GeneratedRSpecFileSource)) return false;
        if (!super.equals(o)) return false;

        GeneratedRSpecFileSource that = (GeneratedRSpecFileSource) o;

        if (nodeCount != that.nodeCount) return false;
        if (!am.equals(that.am)) return false;
        return resourceClass != null ? resourceClass.equals(that.resourceClass) : that.resourceClass == null;
    }

    @Override
    public int hashCode() {
        int result = super.hashCode();
        result = 31 * result + am.hashCode();
        result = 31 * result + (resourceClass != null ? resourceClass.hashCode() : 0);
        result = 31 * result + nodeCount;
        return result;
    }

    @Override
    public String toString() {
        return "GeneratedRSpecFileSource{" +
                "am='" + am + '\'' +
                ", resourceClass='" + resourceClass + '\'' +
                ", nodeCount=" + nodeCount +
                ", type=" + type +
                ", value='" + value + '\'' +
                ", basename='" + basename + '\'' +
                '}';
    }
}
